@@ -1,17 +1,12 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2020 David R. MacIver
-# (david@drmaciver.com), but it contains contributions by others. See
-# CONTRIBUTING.rst for a full list of people who may hold copyright, and
-# consult the git log if you need to determine who owns an individual
-# contribution.
+# Copyright the Hypothesis Authors.
+# Individual contributors are listed in AUTHORS.rst and the git log.
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
 # obtain one at https://mozilla.org/MPL/2.0/.
-#
-# END HEADER
 
 """Hypothesis is a library for writing unit tests which are parametrized by
 some source of data.
@@ -20,9 +15,17 @@ It verifies your code against a wide range of input and minimizes any
 failing examples it finds.
 """
 
-import hypothesis._error_if_old  # noqa  # imported for side-effect of nice error
+import _hypothesis_globals
+
 from hypothesis._settings import HealthCheck, Phase, Verbosity, settings
-from hypothesis.control import assume, event, note, reject, target
+from hypothesis.control import (
+    assume,
+    currently_in_test_context,
+    event,
+    note,
+    reject,
+    target,
+)
 from hypothesis.core import example, find, given, reproduce_failure, seed
 from hypothesis.entry_points import run
 from hypothesis.internal.entropy import register_random
@@ -30,25 +33,29 @@ from hypothesis.utils.conventions import infer
 from hypothesis.version import __version__, __version_info__
 
 __all__ = [
-    "settings",
-    "Verbosity",
     "HealthCheck",
     "Phase",
-    "assume",
-    "reject",
-    "seed",
-    "given",
-    "reproduce_failure",
-    "find",
-    "example",
-    "note",
-    "event",
-    "infer",
-    "register_random",
-    "target",
+    "Verbosity",
     "__version__",
     "__version_info__",
+    "assume",
+    "currently_in_test_context",
+    "event",
+    "example",
+    "find",
+    "given",
+    "infer",
+    "note",
+    "register_random",
+    "reject",
+    "reproduce_failure",
+    "seed",
+    "settings",
+    "target",
 ]
 
 run()
 del run
+
+_hypothesis_globals.in_initialization -= 1
+del _hypothesis_globals
