@@ -20,11 +20,20 @@ from collections.abc import Iterable
 from datetime import datetime, timedelta, timezone
 from functools import lru_cache
 from hashlib import sha384
-from os import getenv
+from os import PathLike, getenv
 from pathlib import Path, PurePath
 from queue import Queue
 from threading import Thread
-from typing import Optional
+from typing import (
+    TYPE_CHECKING,
+    Any,
+    Callable,
+    ClassVar,
+    Literal,
+    Optional,
+    Union,
+    cast,
+)
 from urllib.error import HTTPError, URLError
 from urllib.request import Request, urlopen
 from zipfile import BadZipFile, ZipFile
@@ -32,7 +41,7 @@ from zipfile import BadZipFile, ZipFile
 from hypothesis.configuration import storage_directory
 from hypothesis.errors import HypothesisException, HypothesisWarning
 from hypothesis.internal.conjecture.choice import ChoiceT
-from hypothesis.utils.conventions import not_set
+from hypothesis.utils.conventions import UniqueIdentifier, not_set
 
 __all__ = [
     "DirectoryBasedExampleDatabase",
@@ -43,8 +52,21 @@ __all__ = [
     "ReadOnlyDatabase",
 ]
 
+if TYPE_CHECKING:
+    from typing import TypeAlias
 
-def _usable_dir(path: os.PathLike) -> bool:
+    from watchdog.observers.api import BaseObserver
+
+StrPathT: "TypeAlias" = Union[str, PathLike[str]]
+SaveDataT: "TypeAlias" = tuple[bytes, bytes]  # key, value
+DeleteDataT: "TypeAlias" = tuple[bytes, Optional[bytes]]  # key, value
+ListenerEventT: "TypeAlias" = Union[
+    tuple[Literal["save"], SaveDataT], tuple[Literal["delete"], DeleteDataT]
+]
+ListenerT: "TypeAlias" = Callable[[ListenerEventT], Any]
+
+
+def _usable_dir(path: StrPathT) -> bool:
     """
     Returns True if the desired path can be used as database path because
     either the directory exists and can be used, or its root directory can
@@ -60,7 +82,9 @@ def _usable_dir(path: os.PathLike) -> bool:
         return False
 
 
-def _db_for_path(path=None):
+def _db_for_path(
+    path: Optional[Union[StrPathT, UniqueIdentifier, Literal[":memory:"]]] = None,
+) -> "ExampleDatabase":
     if path is not_set:
         if os.getenv("HYPOTHESIS_DATABASE_FILE") is not None:  # pragma: no cover
             raise HypothesisException(
@@ -81,11 +105,12 @@ def _db_for_path(path=None):
             return InMemoryExampleDatabase()
     if path in (None, ":memory:"):
         return InMemoryExampleDatabase()
+    path = cast(StrPathT, path)
     return DirectoryBasedExampleDatabase(path)
 
 
 class _EDMeta(abc.ABCMeta):
-    def __call__(self, *args, **kwargs):
+    def __call__(self, *args: Any, **kwargs: Any) -> "ExampleDatabase":
         if self is ExampleDatabase:
             return _db_for_path(*args, **kwargs)
         return super().__call__(*args, **kwargs)
@@ -113,9 +138,12 @@ class ExampleDatabase(metaclass=_EDMeta):
     """An abstract base class for storing examples in Hypothesis' internal format.
 
     An ExampleDatabase maps each ``bytes`` key to many distinct ``bytes``
-    values, like a ``Mapping[bytes, AbstractSet[bytes]]``.
+    values, like a ``Mapping[bytes, set[bytes]]``.
     """
 
+    def __init__(self) -> None:
+        self._listeners: list[ListenerT] = []
+
     @abc.abstractmethod
     def save(self, key: bytes, value: bytes) -> None:
         """Save ``value`` under ``key``.
@@ -151,6 +179,78 @@ class ExampleDatabase(metaclass=_EDMeta):
         self.delete(src, value)
         self.save(dest, value)
 
+    def add_listener(self, f: ListenerT, /) -> None:
+        """Add a change listener."""
+        had_listeners = bool(self._listeners)
+        self._listeners.append(f)
+        if not had_listeners:
+            self._start_listening()
+
+    def remove_listener(self, f: ListenerT, /) -> None:
+        """
+        Remove a change listener. If the listener is not present, silently do
+        nothing.
+        """
+        if f not in self._listeners:
+            return
+        self._listeners.remove(f)
+        if not self._listeners:
+            self._stop_listening()
+
+    def clear_listeners(self) -> None:
+        """Remove all change listeners."""
+        had_listeners = bool(self._listeners)
+        self._listeners.clear()
+        if had_listeners:
+            self._stop_listening()
+
+    def _broadcast_change(self, event: ListenerEventT) -> None:
+        """
+        Called when a value has been either added to or deleted from a key in
+        the underlying database store. event_type is one of "save" or "delete".
+
+        ``value`` may be ``None`` for ``event_type == "delete"``, which indicates
+        we don't know what value was deleted from the database.
+
+        Note that you should not assume you are the only reference to the underlying
+        database store. For example, if two DirectoryBasedExampleDatabase reference
+        the same directory, _broadcast_change should be called whenever a file is
+        added or removed from the directory, even if that database was not responsible
+        for changing the file.
+        """
+        for listener in self._listeners:
+            listener(event)
+
+    def _start_listening(self) -> None:
+        """
+        Called when the database adds a change listener, and did not previously
+        have any change listeners. Intended to allow databases to wait to start
+        expensive listening operations until necessary.
+
+        _start_listening and _stop_listening are guaranteed to alternate, so you
+        do not need to handle the case of multiple consecutive _start_listening
+        calls without an intermediate _stop_listening call.
+        """
+        warnings.warn(
+            f"{self.__class__} does not support listening for changes",
+            HypothesisWarning,
+            stacklevel=4,
+        )
+
+    def _stop_listening(self) -> None:
+        """
+        Called whenever no change listeners remain on the database.
+
+        _stop_listening and _start_listening are guaranteed to alternate, so you
+        do not need to handle the case of multiple consecutive _stop_listening
+        calls without an intermediate _start_listening call.
+        """
+        warnings.warn(
+            f"{self.__class__} does not support stopping listening for changes",
+            HypothesisWarning,
+            stacklevel=4,
+        )
+
 
 class InMemoryExampleDatabase(ExampleDatabase):
     """A non-persistent example database, implemented in terms of a dict of sets.
@@ -160,8 +260,9 @@ class InMemoryExampleDatabase(ExampleDatabase):
     does not persist between runs we do not recommend it for general use.
     """
 
-    def __init__(self):
-        self.data = {}
+    def __init__(self) -> None:
+        super().__init__()
+        self.data: dict[bytes, set[bytes]] = {}
 
     def __repr__(self) -> str:
         return f"InMemoryExampleDatabase({self.data!r})"
@@ -170,13 +271,34 @@ class InMemoryExampleDatabase(ExampleDatabase):
         yield from self.data.get(key, ())
 
     def save(self, key: bytes, value: bytes) -> None:
-        self.data.setdefault(key, set()).add(bytes(value))
+        value = bytes(value)
+        values = self.data.setdefault(key, set())
+        changed = value not in values
+        values.add(value)
+
+        if changed:
+            self._broadcast_change(("save", (key, value)))
 
     def delete(self, key: bytes, value: bytes) -> None:
-        self.data.get(key, set()).discard(bytes(value))
+        value = bytes(value)
+        values = self.data.get(key, set())
+        changed = value in values
+        values.discard(value)
+
+        if changed:
+            self._broadcast_change(("delete", (key, value)))
+
+    def _start_listening(self) -> None:
+        # declare compatibility with the listener api, but do the actual
+        # implementation in .delete and .save, since we know we are the only
+        # writer to .data.
+        pass
+
+    def _stop_listening(self) -> None:
+        pass
 
 
-def _hash(key):
+def _hash(key: bytes) -> str:
     return sha384(key).hexdigest()[:16]
 
 
@@ -199,9 +321,16 @@ class DirectoryBasedExampleDatabase(ExampleDatabase):
     the :class:`~hypothesis.database.MultiplexedDatabase` helper.
     """
 
-    def __init__(self, path: os.PathLike) -> None:
+    # we keep a database entry of the full values of all the database keys.
+    # currently only used for inverse mapping of hash -> key in change listening.
+    _metakeys_name: ClassVar[bytes] = b".hypothesis-keys"
+    _metakeys_hash: ClassVar[str] = _hash(_metakeys_name)
+
+    def __init__(self, path: StrPathT) -> None:
+        super().__init__()
         self.path = Path(path)
         self.keypaths: dict[bytes, Path] = {}
+        self._observer: BaseObserver | None = None
 
     def __repr__(self) -> str:
         return f"DirectoryBasedExampleDatabase({self.path!r})"
@@ -214,7 +343,7 @@ class DirectoryBasedExampleDatabase(ExampleDatabase):
         self.keypaths[key] = self.path / _hash(key)
         return self.keypaths[key]
 
-    def _value_path(self, key, value):
+    def _value_path(self, key: bytes, value: bytes) -> Path:
         return self._key_path(key) / _hash(value)
 
     def fetch(self, key: bytes) -> Iterable[bytes]:
@@ -228,11 +357,17 @@ class DirectoryBasedExampleDatabase(ExampleDatabase):
                 pass
 
     def save(self, key: bytes, value: bytes) -> None:
+        key_path = self._key_path(key)
+        if key_path.name != self._metakeys_hash:
+            # add this key to our meta entry of all keys - taking care to avoid
+            # infinite recursion.
+            self.save(self._metakeys_name, key)
+
         # Note: we attempt to create the dir in question now. We
         # already checked for permissions, but there can still be other issues,
         # e.g. the disk is full, or permissions might have been changed.
         try:
-            self._key_path(key).mkdir(exist_ok=True, parents=True)
+            key_path.mkdir(exist_ok=True, parents=True)
             path = self._value_path(key, value)
             if not path.exists():
                 # to mimic an atomic write, create and write in a temporary
@@ -255,11 +390,16 @@ class DirectoryBasedExampleDatabase(ExampleDatabase):
         if src == dest:
             self.save(src, value)
             return
+
+        src_path = self._value_path(src, value)
+        dest_path = self._value_path(dest, value)
+        # if the dest key path does not exist, os.renames will create it for us,
+        # and we will never track its creation in the meta keys entry. Do so now.
+        if not self._key_path(dest).exists():
+            self.save(self._metakeys_name, dest)
+
         try:
-            os.renames(
-                self._value_path(src, value),
-                self._value_path(dest, value),
-            )
+            os.renames(src_path, dest_path)
         except OSError:
             self.delete(src, value)
             self.save(dest, value)
@@ -270,6 +410,114 @@ class DirectoryBasedExampleDatabase(ExampleDatabase):
         except OSError:
             pass
 
+    def _start_listening(self) -> None:
+        try:
+            from watchdog.events import (
+                DirCreatedEvent,
+                DirDeletedEvent,
+                DirMovedEvent,
+                FileCreatedEvent,
+                FileDeletedEvent,
+                FileMovedEvent,
+                FileSystemEventHandler,
+            )
+            from watchdog.observers import Observer
+        except ImportError:
+            warnings.warn(
+                f"listening for changes in a {self.__class__.__name__} "
+                "requires the watchdog library. To install, run "
+                "`pip install hypothesis[watchdog]`",
+                HypothesisWarning,
+                stacklevel=4,
+            )
+            return
+
+        hash_to_key = {_hash(key): key for key in self.fetch(self._metakeys_name)}
+        _metakeys_hash = self._metakeys_hash
+        _broadcast_change = self._broadcast_change
+
+        class Handler(FileSystemEventHandler):
+            def on_created(
+                _self, event: Union[FileCreatedEvent, DirCreatedEvent]
+            ) -> None:
+                # we only registered for the file creation event
+                assert not isinstance(event, DirCreatedEvent)
+                # watchdog events are only bytes if we passed a byte path to
+                # .schedule
+                assert isinstance(event.src_path, str)
+
+                value_path = Path(event.src_path)
+                # the parent dir represents the key, and its name is the key hash
+                key_hash = value_path.parent.name
+
+                if key_hash == _metakeys_hash:
+                    hash_to_key[value_path.name] = value_path.read_bytes()
+                    return
+
+                key = hash_to_key.get(key_hash)
+                if key is None:  # pragma: no cover
+                    # we didn't recognize this key. This shouldn't ever happen,
+                    # but some race condition trickery might cause this.
+                    return
+
+                try:
+                    value = value_path.read_bytes()
+                except OSError:  # pragma: no cover
+                    return
+
+                _broadcast_change(("save", (key, value)))
+
+            def on_deleted(
+                self, event: Union[FileDeletedEvent, DirDeletedEvent]
+            ) -> None:
+                assert not isinstance(event, DirDeletedEvent)
+                assert isinstance(event.src_path, str)
+
+                value_path = Path(event.src_path)
+                key = hash_to_key.get(value_path.parent.name)
+                if key is None:  # pragma: no cover
+                    return
+
+                _broadcast_change(("delete", (key, None)))
+
+            def on_moved(self, event: Union[FileMovedEvent, DirMovedEvent]) -> None:
+                assert not isinstance(event, DirMovedEvent)
+                assert isinstance(event.src_path, str)
+                assert isinstance(event.dest_path, str)
+
+                src_path = Path(event.src_path)
+                dest_path = Path(event.dest_path)
+                k1 = hash_to_key.get(src_path.parent.name)
+                k2 = hash_to_key.get(dest_path.parent.name)
+
+                if k1 is None or k2 is None:  # pragma: no cover
+                    return
+
+                try:
+                    value = dest_path.read_bytes()
+                except OSError:  # pragma: no cover
+                    return
+
+                _broadcast_change(("delete", (k1, value)))
+                _broadcast_change(("save", (k2, value)))
+
+        self._observer = Observer()
+        self._observer.schedule(
+            Handler(),
+            # remove type: ignore when released
+            # https://github.com/gorakhargosh/watchdog/pull/1096
+            self.path,  # type: ignore
+            recursive=True,
+            event_filter=[FileCreatedEvent, FileDeletedEvent, FileMovedEvent],
+        )
+        self._observer.start()
+
+    def _stop_listening(self) -> None:
+        assert self._observer is not None
+        self._observer.stop()
+        self._observer.join()
+        self._observer = None
+
 
 class ReadOnlyDatabase(ExampleDatabase):
     """A wrapper to make the given database read-only.
@@ -283,6 +531,7 @@ class ReadOnlyDatabase(ExampleDatabase):
     """
 
     def __init__(self, db: ExampleDatabase) -> None:
+        super().__init__()
         assert isinstance(db, ExampleDatabase)
         self._wrapped = db
 
@@ -298,6 +547,13 @@ class ReadOnlyDatabase(ExampleDatabase):
     def delete(self, key: bytes, value: bytes) -> None:
         pass
 
+    def _start_listening(self) -> None:
+        # we're read only, so there are no changes to broadcast.
+        pass
+
+    def _stop_listening(self) -> None:
+        pass
+
 
 class MultiplexedDatabase(ExampleDatabase):
     """A wrapper around multiple databases.
@@ -326,6 +582,7 @@ class MultiplexedDatabase(ExampleDatabase):
     """
 
     def __init__(self, *dbs: ExampleDatabase) -> None:
+        super().__init__()
         assert all(isinstance(db, ExampleDatabase) for db in dbs)
         self._wrapped = dbs
 
@@ -352,6 +609,14 @@ class MultiplexedDatabase(ExampleDatabase):
         for db in self._wrapped:
             db.move(src, dest, value)
 
+    def _start_listening(self) -> None:
+        for db in self._wrapped:
+            db.add_listener(self._broadcast_change)
+
+    def _stop_listening(self) -> None:
+        for db in self._wrapped:
+            db.remove_listener(self._broadcast_change)
+
 
 class GitHubArtifactDatabase(ExampleDatabase):
     """
@@ -396,7 +661,7 @@ class GitHubArtifactDatabase(ExampleDatabase):
     .. code-block:: yaml
 
         - name: Download example database
-          uses: dawidd6/action-download-artifact@v2.24.3
+          uses: dawidd6/action-download-artifact@v9
           with:
             name: hypothesis-example-db
             path: .hypothesis/examples
@@ -429,8 +694,9 @@ class GitHubArtifactDatabase(ExampleDatabase):
         repo: str,
         artifact_name: str = "hypothesis-example-db",
         cache_timeout: timedelta = timedelta(days=1),
-        path: Optional[os.PathLike] = None,
+        path: Optional[StrPathT] = None,
     ):
+        super().__init__()
         self.owner = owner
         self.repo = repo
         self.artifact_name = artifact_name
@@ -691,6 +957,7 @@ class BackgroundWriteDatabase(ExampleDatabase):
     """
 
     def __init__(self, db: ExampleDatabase) -> None:
+        super().__init__()
         self._db = db
         self._queue: Queue[tuple[str, tuple[bytes, ...]]] = Queue()
         self._thread = Thread(target=self._worker, daemon=True)
@@ -727,9 +994,54 @@ class BackgroundWriteDatabase(ExampleDatabase):
     def move(self, src: bytes, dest: bytes, value: bytes) -> None:
         self._queue.put(("move", (src, dest, value)))
 
+    def _start_listening(self) -> None:
+        self._db.add_listener(self._broadcast_change)
 
-def ir_to_bytes(ir: Iterable[ChoiceT], /) -> bytes:
-    """Serialize a list of IR elements to a bytestring.  Inverts ir_from_bytes."""
+    def _stop_listening(self) -> None:
+        self._db.remove_listener(self._broadcast_change)
+
+
+def _pack_uleb128(value: int) -> bytes:
+    """
+    Serialize an integer into variable-length bytes. For each byte, the first 7
+    bits represent (part of) the integer, while the last bit indicates whether the
+    integer continues into the next byte.
+
+    https://en.wikipedia.org/wiki/LEB128
+    """
+    parts = bytearray()
+    assert value >= 0
+    while True:
+        # chop off 7 bits
+        byte = value & ((1 << 7) - 1)
+        value >>= 7
+        # set the continuation bit if we have more left
+        if value:
+            byte |= 1 << 7
+
+        parts.append(byte)
+        if not value:
+            break
+    return bytes(parts)
+
+
+def _unpack_uleb128(buffer: bytes) -> tuple[int, int]:
+    """
+    Inverts _pack_uleb128, and also returns the index at which at which we stopped
+    reading.
+    """
+    value = 0
+    for i, byte in enumerate(buffer):
+        n = byte & ((1 << 7) - 1)
+        value |= n << (i * 7)
+
+        if not byte >> 7:
+            break
+    return (i + 1, value)
+
+
+def choices_to_bytes(ir: Iterable[ChoiceT], /) -> bytes:
+    """Serialize a list of IR elements to a bytestring.  Inverts choices_from_bytes."""
     # We use a custom serialization format for this, which might seem crazy - but our
     # data is a flat sequence of elements, and standard tools like protobuf or msgpack
     # don't deal well with e.g. nonstandard bit-pattern-NaNs, or invalid-utf8 unicode.
@@ -762,13 +1074,13 @@ def ir_to_bytes(ir: Iterable[ChoiceT], /) -> bytes:
             parts.append((tag | size).to_bytes(1, "big"))
         else:
             parts.append((tag | 0b11111).to_bytes(1, "big"))
-            parts.append(struct.pack("!H", size))
+            parts.append(_pack_uleb128(size))
         parts.append(elem)
 
     return b"".join(parts)
 
 
-def _ir_from_bytes(buffer: bytes, /) -> tuple[ChoiceT, ...]:
+def _choices_from_bytes(buffer: bytes, /) -> tuple[ChoiceT, ...]:
     # See above for an explanation of the format.
     parts: list[ChoiceT] = []
     idx = 0
@@ -781,8 +1093,8 @@ def _ir_from_bytes(buffer: bytes, /) -> tuple[ChoiceT, ...]:
             parts.append(bool(size))
             continue
         if size == 0b11111:
-            (size,) = struct.unpack_from("!H", buffer, offset=idx)
-            idx += 2
+            (offset, size) = _unpack_uleb128(buffer[idx:])
+            idx += offset
         chunk = buffer[idx : idx + size]
         idx += size
 
@@ -799,15 +1111,15 @@ def _ir_from_bytes(buffer: bytes, /) -> tuple[ChoiceT, ...]:
     return tuple(parts)
 
 
-def ir_from_bytes(buffer: bytes, /) -> Optional[tuple[ChoiceT, ...]]:
+def choices_from_bytes(buffer: bytes, /) -> Optional[tuple[ChoiceT, ...]]:
     """
-    Deserialize a bytestring to a tuple of choices. Inverts ir_to_bytes.
+    Deserialize a bytestring to a tuple of choices. Inverts choices_to_bytes.
 
     Returns None if the given bytestring is not a valid serialization of choice
     sequences.
     """
     try:
-        return _ir_from_bytes(buffer)
+        return _choices_from_bytes(buffer)
     except Exception:
         # deserialization error, eg because our format changed or someone put junk
         # data in the db.
