@@ -15,6 +15,7 @@ from typing import Literal, Optional, Union
 
 from hypothesis.control import reject
 from hypothesis.errors import InvalidArgument
+from hypothesis.internal.conjecture.data import ConjectureData
 from hypothesis.internal.filtering import (
     get_float_predicate_bounds,
     get_integer_predicate_bounds,
@@ -47,15 +48,15 @@ from hypothesis.strategies._internal.utils import cacheable, defines_strategy
 Real = Union[int, float, Fraction, Decimal]
 
 
-class IntegersStrategy(SearchStrategy):
-    def __init__(self, start, end):
+class IntegersStrategy(SearchStrategy[int]):
+    def __init__(self, start: Optional[int], end: Optional[int]) -> None:
         assert isinstance(start, int) or start is None
         assert isinstance(end, int) or end is None
         assert start is None or end is None or start <= end
         self.start = start
         self.end = end
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         if self.start is None and self.end is None:
             return "integers()"
         if self.end is None:
@@ -64,26 +65,23 @@ class IntegersStrategy(SearchStrategy):
             return f"integers(max_value={self.end})"
         return f"integers({self.start}, {self.end})"
 
-    def do_draw(self, data):
+    def do_draw(self, data: ConjectureData) -> int:
         # For bounded integers, make the bounds and near-bounds more likely.
-        forced = None
+        weights = None
         if (
             self.end is not None
             and self.start is not None
             and self.end - self.start > 127
         ):
-            bits = data.draw_integer(0, 127)
-            forced = {
-                122: self.start,
-                123: self.start,
-                124: self.end,
-                125: self.end,
-                126: self.start + 1,
-                127: self.end - 1,
-            }.get(bits)
+            weights = {
+                self.start: (2 / 128),
+                self.start + 1: (1 / 128),
+                self.end - 1: (1 / 128),
+                self.end: (2 / 128),
+            }
 
         return data.draw_integer(
-            min_value=self.start, max_value=self.end, forced=forced
+            min_value=self.start, max_value=self.end, weights=weights
         )
 
     def filter(self, condition):
@@ -144,7 +142,7 @@ def integers(
     return IntegersStrategy(min_value, max_value)
 
 
-class FloatStrategy(SearchStrategy):
+class FloatStrategy(SearchStrategy[float]):
     """A strategy for floating point numbers."""
 
     def __init__(
@@ -176,16 +174,13 @@ class FloatStrategy(SearchStrategy):
         self.allow_nan = allow_nan
         self.smallest_nonzero_magnitude = smallest_nonzero_magnitude
 
-    def __repr__(self):
-        return "{}(min_value={}, max_value={}, allow_nan={}, smallest_nonzero_magnitude={})".format(
-            self.__class__.__name__,
-            self.min_value,
-            self.max_value,
-            self.allow_nan,
-            self.smallest_nonzero_magnitude,
-        )
+    def __repr__(self) -> str:
+        return (
+            f"{self.__class__.__name__}({self.min_value=}, {self.max_value=}, "
+            f"{self.allow_nan=}, {self.smallest_nonzero_magnitude=})"
+        ).replace("self.", "")
 
-    def do_draw(self, data):
+    def do_draw(self, data: ConjectureData) -> float:
         return data.draw_float(
             min_value=self.min_value,
             max_value=self.max_value,
@@ -383,22 +378,30 @@ def floats(
     if min_value is not None and (
         exclude_min or (min_arg is not None and min_value < min_arg)
     ):
-        min_value = next_up_normal(min_value, width, assumed_allow_subnormal)
+        min_value = next_up_normal(
+            min_value, width, allow_subnormal=assumed_allow_subnormal
+        )
         if min_value == min_arg:
             assert min_value == min_arg == 0
             assert is_negative(min_arg)
             assert not is_negative(min_value)
-            min_value = next_up_normal(min_value, width, assumed_allow_subnormal)
+            min_value = next_up_normal(
+                min_value, width, allow_subnormal=assumed_allow_subnormal
+            )
         assert min_value > min_arg  # type: ignore
     if max_value is not None and (
         exclude_max or (max_arg is not None and max_value > max_arg)
     ):
-        max_value = next_down_normal(max_value, width, assumed_allow_subnormal)
+        max_value = next_down_normal(
+            max_value, width, allow_subnormal=assumed_allow_subnormal
+        )
         if max_value == max_arg:
             assert max_value == max_arg == 0
             assert is_negative(max_value)
             assert not is_negative(max_arg)
-            max_value = next_down_normal(max_value, width, assumed_allow_subnormal)
+            max_value = next_down_normal(
+                max_value, width, allow_subnormal=assumed_allow_subnormal
+            )
         assert max_value < max_arg  # type: ignore
 
     if min_value == -math.inf:
@@ -498,7 +501,7 @@ def floats(
 
     if width < 64:
 
-        def downcast(x):
+        def downcast(x: float) -> float:
             try:
                 return float_of(x, width)
             except OverflowError:  # pragma: no cover
@@ -508,10 +511,10 @@ def floats(
     return result
 
 
-class NanStrategy(SearchStrategy):
+class NanStrategy(SearchStrategy[float]):
     """Strategy for sampling the space of nan float values."""
 
-    def do_draw(self, data):
+    def do_draw(self, data: ConjectureData) -> float:
         # Nans must have all exponent bits and the first mantissa bit set, so
         # we generate by taking 64 random bits and setting the required ones.
         sign_bit = int(data.draw_boolean()) << 63
