@@ -11,10 +11,10 @@
 import gc
 import inspect
 import json
+import os
 import random
 import sys
 import time as time_module
-from collections import defaultdict
 from functools import wraps
 from pathlib import Path
 
@@ -54,15 +54,13 @@ def pytest_configure(config):
         "markers",
         "xp_min_version(api_version): run when greater or equal to api_version",
     )
+    config.addinivalue_line("markers", "xf_crosshair: selection for xfailing symbolics")
 
     if config.getoption("--hypothesis-benchmark-shrinks"):
         # we'd like to support xdist here, but a session-scope fixture won't
         # be enough: https://github.com/pytest-dev/pytest-xdist/issues/271.
         # Need a lockfile or equivalent.
 
-        assert not hasattr(
-            config, "workerinput"
-        ), "--hypothesis-benchmark-shrinks does not currently support xdist. Run without -n"
         assert config.getoption(
             "--hypothesis-benchmark-output"
         ), "must specify shrinking output file"
@@ -75,7 +73,6 @@ def pytest_addoption(parser):
     parser.addoption("--hypothesis-update-outputs", action="store_true")
     parser.addoption("--hypothesis-benchmark-shrinks", type=str, choices=["new", "old"])
     parser.addoption("--hypothesis-benchmark-output", type=str)
-    parser.addoption("--hypothesis-learn-to-normalize", action="store_true")
 
     # New in pytest 6, so we add a shim on old versions to avoid missing-arg errors
     arg = "--durations-min"
@@ -95,6 +92,13 @@ def warns_or_raises(request):
         return pytest.warns
 
 
+# crosshair needs actual time for its path timeouts; load it before patching
+try:
+    import hypothesis_crosshair_provider.crosshair_provider  # noqa: F401
+except ImportError:
+    pass
+
+
 @pytest.fixture(scope="function", autouse=True)
 def _consistently_increment_time(monkeypatch):
     """Rather than rely on real system time we monkey patch time.time so that
@@ -215,12 +219,18 @@ def pytest_runtest_call(item):
         )
 
 
-shrink_calls = defaultdict(list)
-shrink_time = defaultdict(list)
 timer = time_module.process_time
 
 
-def _benchmark_shrinks(item):
+def _worker_path(session: pytest.Session) -> Path:
+    return (
+        Path(session.config.getoption("--hypothesis-benchmark-output")).parent
+        # https://pytest-xdist.readthedocs.io/en/stable/how-to.html#envvar-PYTEST_XDIST_WORKER
+        / f"shrinking_results_{os.environ['PYTEST_XDIST_WORKER']}.json"
+    )
+
+
+def _benchmark_shrinks(item: pytest.Function) -> None:
     from hypothesis.internal.conjecture.shrinker import Shrinker
 
     # this isn't perfect, but it is cheap!
@@ -228,14 +238,16 @@ def _benchmark_shrinks(item):
         pytest.skip("(probably) does not call minimal()")
 
     actual_shrink = Shrinker.shrink
+    shrink_calls = []
+    shrink_time = []
 
     def shrink(self, *args, **kwargs):
+        nonlocal shrink_calls
+        nonlocal shrink_time
         start_t = timer()
         result = actual_shrink(self, *args, **kwargs)
-        # remove leading hypothesis-python/tests/...
-        nodeid = item.nodeid.rsplit("/", 1)[1]
-        shrink_calls[nodeid].append(self.engine.call_count - self.initial_calls)
-        shrink_time[nodeid].append(timer() - start_t)
+        shrink_calls.append(self.engine.call_count - self.initial_calls)
+        shrink_time.append(timer() - start_t)
         return result
 
     monkeypatch = MonkeyPatch()
@@ -249,15 +261,39 @@ def _benchmark_shrinks(item):
 
     monkeypatch.undo()
 
+    # remove leading hypothesis-python/tests/...
+    nodeid = item.nodeid.rsplit("/", 1)[1]
+
+    results_p = _worker_path(item.session)
+    if not results_p.exists():
+        results_p.write_text(json.dumps({"calls": {}, "time": {}}))
+
+    data = json.loads(results_p.read_text())
+    data["calls"][nodeid] = shrink_calls
+    data["time"][nodeid] = shrink_time
+    results_p.write_text(json.dumps(data))
+
 
 def pytest_sessionfinish(session, exitstatus):
     if not (mode := session.config.getoption("--hypothesis-benchmark-shrinks")):
         return
-    p = Path(session.config.getoption("--hypothesis-benchmark-output"))
-    results = {mode: {"calls": shrink_calls, "time": shrink_time}}
-    if not p.exists():
-        p.write_text(json.dumps(results))
+    # only run on the controller process, not the workers
+    if hasattr(session.config, "workerinput"):
+        return
+
+    results = {"calls": {}, "time": {}}
+    output_p = Path(session.config.getoption("--hypothesis-benchmark-output"))
+    for p in output_p.parent.iterdir():
+        if p.name.startswith("shrinking_results_"):
+            worker_results = json.loads(p.read_text())
+            results["calls"] |= worker_results["calls"]
+            results["time"] |= worker_results["time"]
+            p.unlink()
+
+    results = {mode: results}
+    if not output_p.exists():
+        output_p.write_text(json.dumps(results))
     else:
-        data = json.loads(p.read_text())
+        data = json.loads(output_p.read_text())
         data[mode] = results[mode]
-        p.write_text(json.dumps(data))
+        output_p.write_text(json.dumps(data))
