@@ -11,7 +11,7 @@
 import itertools
 import math
 import sys
-from contextlib import contextmanager
+from contextlib import contextmanager, nullcontext
 from random import Random
 from typing import Optional
 
@@ -32,10 +32,11 @@ from hypothesis.errors import (
     BackendCannotProceed,
     Flaky,
     HypothesisException,
+    HypothesisWarning,
     InvalidArgument,
     Unsatisfiable,
 )
-from hypothesis.internal.compat import int_to_bytes
+from hypothesis.internal.compat import WINDOWS, int_to_bytes
 from hypothesis.internal.conjecture.data import ConjectureData, PrimitiveProvider
 from hypothesis.internal.conjecture.engine import ConjectureRunner
 from hypothesis.internal.conjecture.providers import (
@@ -250,7 +251,7 @@ def test_backend_can_shrink_floats():
 
 
 # mostly a shoehorned coverage test until the shrinker is migrated to the ir
-# and calls cached_test_function_ir with backends consistently.
+# and calls cached_test_function with backends consistently.
 @given(nodes())
 def test_new_conjecture_data_with_backend(node):
     def test(data):
@@ -258,7 +259,7 @@ def test_new_conjecture_data_with_backend(node):
 
     with temp_register_backend("prng", PrngProvider):
         runner = ConjectureRunner(test, settings=settings(backend="prng"))
-        runner.cached_test_function_ir([node.value])
+        runner.cached_test_function([node.value])
 
 
 # trivial provider for tests which don't care about drawn distributions.
@@ -443,7 +444,7 @@ def test_realization_with_verbosity(verbosity):
 
         with capture_out() as out:
             test_function()
-        assert "Trying example: <symbolics>" in out.getvalue()
+        assert "Trying example: test_function(\n    f=<symbolic>,\n)" in out.getvalue()
 
 
 @pytest.mark.parametrize("verbosity", [Verbosity.verbose, Verbosity.debug])
@@ -596,3 +597,41 @@ def test_available_providers_deprecation():
 
     with pytest.raises(ImportError):
         from hypothesis.internal.conjecture.data import does_not_exist  # noqa
+
+
+@pytest.mark.parametrize("backend", AVAILABLE_PROVIDERS.keys())
+@pytest.mark.parametrize(
+    "strategy", [st.integers(), st.text(), st.floats(), st.booleans(), st.binary()]
+)
+def test_can_generate_from_all_available_providers(backend, strategy):
+    @given(strategy)
+    @settings(backend=backend, database=None)
+    def f(x):
+        raise ValueError
+
+    with (
+        pytest.raises(ValueError),
+        (
+            pytest.warns(
+                HypothesisWarning, match="/dev/urandom is not available on windows"
+            )
+            if backend == "hypothesis-urandom" and WINDOWS
+            else nullcontext()
+        ),
+    ):
+        f()
+
+
+def test_saves_on_fatal_error_with_backend():
+    with temp_register_backend("trivial", TrivialProvider):
+        db = InMemoryExampleDatabase()
+
+        @given(st.integers())
+        @settings(backend="trivial", database=db)
+        def test_function(n):
+            raise BaseException("marker")
+
+        with pytest.raises(BaseException, match="marker"):
+            test_function()
+
+        assert len(db.data) == 1
