@@ -8,6 +8,7 @@
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
 # obtain one at https://mozilla.org/MPL/2.0/.
 
+import math
 import sys
 
 import pytest
@@ -16,7 +17,7 @@ from hypothesis import HealthCheck, assume, example, given, settings, strategies
 from hypothesis.internal.compat import ceil, extract_bits, floor
 from hypothesis.internal.conjecture import floats as flt
 from hypothesis.internal.conjecture.engine import ConjectureRunner
-from hypothesis.internal.floats import float_to_int
+from hypothesis.internal.floats import SIGNALING_NAN, float_to_int
 
 EXPONENTS = list(range(flt.MAX_EXPONENT + 1))
 assert len(EXPONENTS) == 2**11
@@ -129,7 +130,7 @@ def float_runner(start, condition, *, kwargs=None):
             data.mark_interesting()
 
     runner = ConjectureRunner(test_function)
-    runner.cached_test_function_ir((float(start),))
+    runner.cached_test_function((float(start),))
     assert runner.interesting_examples
     return runner
 
@@ -200,3 +201,9 @@ def test_reject_out_of_bounds_floats_while_shrinking():
     kwargs = {"min_value": 103.0}
     g = minimal_from(103.1, lambda x: x >= 100, kwargs=kwargs)
     assert g == 103.0
+
+
+@pytest.mark.parametrize("nan", [-math.nan, SIGNALING_NAN, -SIGNALING_NAN])
+def test_shrinks_to_canonical_nan(nan):
+    shrunk = minimal_from(nan, math.isnan)
+    assert float_to_int(shrunk) == float_to_int(math.nan)
