@@ -1,17 +1,12 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2020 David R. MacIver
-# (david@drmaciver.com), but it contains contributions by others. See
-# CONTRIBUTING.rst for a full list of people who may hold copyright, and
-# consult the git log if you need to determine who owns an individual
-# contribution.
+# Copyright the Hypothesis Authors.
+# Individual contributors are listed in AUTHORS.rst and the git log.
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
 # obtain one at https://mozilla.org/MPL/2.0/.
-#
-# END HEADER
 
 import itertools
 
@@ -129,10 +124,11 @@ def test_iteration_with_dead_nodes():
 
 
 def test_learning_is_just_checking_when_fully_explored():
-    count = [0]
+    count = 0
 
     def accept(s):
-        count[0] += 1
+        nonlocal count
+        count += 1
         return len(s) <= 5 and all(c == 0 for c in s)
 
     learner = LStar(accept)
@@ -143,20 +139,21 @@ def test_learning_is_just_checking_when_fully_explored():
 
     assert list(learner.dfa.all_matching_strings()) == [bytes(n) for n in range(6)]
 
-    (prev,) = count
+    prev = count
 
     learner.learn([2] * 11)
 
-    calls = count[0] - prev
+    calls = count - prev
 
     assert calls == 1
 
 
 def test_canonicalises_values_to_zero_where_appropriate():
-    calls = [0]
+    calls = 0
 
     def member(s):
-        calls[0] += 1
+        nonlocal calls
+        calls += 1
         return len(s) == 10
 
     learner = LStar(member)
@@ -164,11 +161,11 @@ def test_canonicalises_values_to_zero_where_appropriate():
     learner.learn(bytes(10))
     learner.learn(bytes(11))
 
-    (prev,) = calls
+    prev = calls
 
     assert learner.dfa.matches(bytes([1] * 10))
 
-    assert calls[0] == prev
+    assert calls == prev
 
 
 def test_normalizing_defaults_to_zero():
@@ -204,25 +201,6 @@ def test_learning_large_dfa():
         assert i == int.from_bytes(s, "big")
 
 
-@st.composite
-def byte_order(draw):
-    ls = draw(st.permutations(range(256)))
-    n = draw(st.integers(0, len(ls)))
-    return ls[:n]
-
-
-@example({0}, [1])
-@given(st.sets(st.integers(0, 255)), byte_order())
-def test_learning_always_changes_generation(chars, order):
-    learner = LStar(lambda s: len(s) == 1 and s[0] in chars)
-    for c in order:
-        prev = learner.generation
-        s = bytes([c])
-        if learner.dfa.matches(s) != learner.member(s):
-            learner.learn(s)
-            assert learner.generation > prev
-
-
 def varint_predicate(b):
     if not b:
         return False
@@ -239,7 +217,7 @@ def varint(draw):
     result.append(draw(st.integers(1, 255)))
     n = result[0] & 15
     assume(n > 0)
-    value = draw(st.integers(10, 256 ** n - 1))
+    value = draw(st.integers(10, 256**n - 1))
     result.extend(value.to_bytes(n, "big"))
     return bytes(result)
 
