@@ -30,7 +30,7 @@ def test_optimises_to_maximum():
             data.target_observations["m"] = data.draw_integer(0, 2**8 - 1)
 
         runner = ConjectureRunner(test, settings=TEST_SETTINGS)
-        runner.cached_test_function_ir((0,))
+        runner.cached_test_function((0,))
 
         try:
             runner.optimise_targets()
@@ -53,8 +53,8 @@ def test_optimises_multiple_targets():
             data.target_observations["m + n"] = m + n
 
         runner = ConjectureRunner(test, settings=TEST_SETTINGS)
-        runner.cached_test_function_ir((200, 0))
-        runner.cached_test_function_ir((0, 200))
+        runner.cached_test_function((200, 0))
+        runner.cached_test_function((0, 200))
 
         try:
             runner.optimise_targets()
@@ -71,11 +71,11 @@ def test_optimises_when_last_element_is_empty():
 
         def test(data):
             data.target_observations["n"] = data.draw_integer(0, 2**8 - 1)
-            data.start_example(label=1)
-            data.stop_example()
+            data.start_span(label=1)
+            data.stop_span()
 
         runner = ConjectureRunner(test, settings=TEST_SETTINGS)
-        runner.cached_test_function_ir((250,))
+        runner.cached_test_function((250,))
 
         try:
             runner.optimise_targets()
@@ -92,13 +92,13 @@ def test_can_optimise_last_with_following_empty():
             for _ in range(100):
                 data.draw_integer(0, 3)
             data.target_observations[""] = data.draw_integer(0, 2**8 - 1)
-            data.start_example(1)
-            data.stop_example()
+            data.start_span(1)
+            data.stop_span()
 
         runner = ConjectureRunner(
             test, settings=settings(TEST_SETTINGS, max_examples=100)
         )
-        runner.cached_test_function_ir((0,) * 101)
+        runner.cached_test_function((0,) * 101)
 
         with pytest.raises(RunIsComplete):
             runner.optimise_targets()
@@ -121,7 +121,7 @@ def test_can_find_endpoints_of_a_range(lower, upper, score_up):
         runner = ConjectureRunner(
             test, settings=settings(TEST_SETTINGS, max_examples=1000)
         )
-        runner.cached_test_function_ir(((lower + upper) // 2,))
+        runner.cached_test_function(((lower + upper) // 2,))
 
         try:
             runner.optimise_targets()
@@ -146,7 +146,7 @@ def test_targeting_can_drive_length_very_high():
         # extend here to ensure we get a valid (non-overrun) test case. The
         # outcome of the test case doesn't really matter as long as we have
         # something for the runner to optimize.
-        runner.cached_test_function_ir([], extend=50)
+        runner.cached_test_function([], extend=50)
 
         try:
             runner.optimise_targets()
@@ -167,7 +167,7 @@ def test_optimiser_when_test_grows_buffer_to_invalid():
                 data.mark_invalid()
 
         runner = ConjectureRunner(test, settings=TEST_SETTINGS)
-        runner.cached_test_function_ir((0,) * 10)
+        runner.cached_test_function((0,) * 10)
 
         try:
             runner.optimise_targets()
@@ -181,18 +181,18 @@ def test_can_patch_up_examples():
     with deterministic_PRNG():
 
         def test(data):
-            data.start_example(42)
+            data.start_span(42)
             m = data.draw_integer(0, 2**6 - 1)
             data.target_observations["m"] = m
             for _ in range(m):
                 data.draw_boolean()
-            data.stop_example()
+            data.stop_span()
             for i in range(4):
                 if i != data.draw_integer(0, 2**8 - 1):
                     data.mark_invalid()
 
         runner = ConjectureRunner(test, settings=TEST_SETTINGS)
-        d = runner.cached_test_function_ir((0, 0, 1, 2, 3, 4))
+        d = runner.cached_test_function((0, 0, 1, 2, 3, 4))
         assert d.status == Status.VALID
 
         try:
@@ -215,7 +215,7 @@ def test_optimiser_when_test_grows_buffer_to_overflow():
                     data.mark_invalid()
 
             runner = ConjectureRunner(test, settings=TEST_SETTINGS)
-            runner.cached_test_function_ir((0,) * 10)
+            runner.cached_test_function((0,) * 10)
 
             try:
                 runner.optimise_targets()
@@ -267,7 +267,7 @@ def test_optimising_all_nodes(node):
         runner = ConjectureRunner(
             test, settings=settings(TEST_SETTINGS, max_examples=50)
         )
-        runner.cached_test_function_ir([node.value])
+        runner.cached_test_function([node.value])
 
         try:
             runner.optimise_targets()
