@@ -13,7 +13,11 @@ import itertools
 import pytest
 
 from hypothesis import HealthCheck, Phase, settings, strategies as st
-from hypothesis.database import InMemoryExampleDatabase, choices_to_bytes
+from hypothesis.database import (
+    InMemoryExampleDatabase,
+    choices_from_bytes,
+    choices_to_bytes,
+)
 from hypothesis.internal.conjecture.data import Status
 from hypothesis.internal.conjecture.engine import ConjectureRunner, RunIsComplete
 from hypothesis.internal.entropy import deterministic_PRNG
@@ -68,10 +72,6 @@ def test_pareto_front_omits_invalid_examples():
         assert len(runner.pareto_front) == 0
 
 
-# at some point this test regressed. It's not clear how long ago, because it
-# happened to pass by chance on deterministic rng with seed 0 for at least
-# some amount of time.
-@pytest.mark.xfail(strict=False)
 def test_database_contains_only_pareto_front():
     with deterministic_PRNG():
 
@@ -105,11 +105,12 @@ def test_database_contains_only_pareto_front():
         assert len(values) == len(runner.pareto_front)
 
         for data in runner.pareto_front:
-            assert data.buffer in values
+            assert choices_to_bytes(data.choices) in values
             assert data in runner.pareto_front
 
-        for k in values:
-            assert runner.cached_test_function(k) in runner.pareto_front
+        for b in values:
+            choices = choices_from_bytes(b)
+            assert runner.cached_test_function(choices) in runner.pareto_front
 
 
 def test_clears_defunct_pareto_front():
@@ -205,9 +206,9 @@ def test_uses_tags_in_calculating_pareto_front():
         def test(data):
             data.target_observations[""] = 1
             if data.draw_boolean():
-                data.start_example(11)
+                data.start_span(11)
                 data.draw_integer(0, 2**8 - 1)
-                data.stop_example()
+                data.stop_span()
 
         runner = ConjectureRunner(
             test,
@@ -233,7 +234,7 @@ def test_optimises_the_pareto_front():
         settings=settings(max_examples=10000, database=InMemoryExampleDatabase()),
         database_key=b"stuff",
     )
-    runner.cached_test_function_ir([255] * 20 + [0])
+    runner.cached_test_function([255] * 20 + [0])
     runner.pareto_optimise()
 
     assert len(runner.pareto_front) == 6
@@ -254,7 +255,7 @@ def test_does_not_optimise_the_pareto_front_if_interesting():
         database_key=b"stuff",
     )
 
-    runner.cached_test_function_ir([0])
+    runner.cached_test_function([0])
     runner.pareto_optimise = None
     runner.optimise_targets()
 
@@ -276,7 +277,7 @@ def test_stops_optimising_once_interesting():
         database_key=b"stuff",
     )
 
-    data = runner.cached_test_function_ir([hi])
+    data = runner.cached_test_function([hi])
     assert data.status == Status.VALID
     runner.pareto_optimise()
     assert runner.call_count <= 20
