@@ -13,8 +13,9 @@ import sys
 import tempfile
 import time
 import unicodedata
+from typing import get_args
 
-from hypothesis import assume, given, strategies as st
+from hypothesis import given, strategies as st
 from hypothesis.internal import charmap as cm
 from hypothesis.internal.intervalsets import IntervalSet
 
@@ -43,44 +44,29 @@ def assert_valid_range_list(ls):
         assert ls[i][-1] < ls[i + 1][0]
 
 
-@given(
-    st.sets(st.sampled_from(cm.categories())),
-    st.sets(st.sampled_from(cm.categories())) | st.none(),
-)
-def test_query_matches_categories(exclude, include):
-    values = cm.query(exclude, include).intervals
+@given(st.sets(st.sampled_from(cm.categories())))
+def test_query_matches_categories(cats):
+    values = cm.query(categories=cats).intervals
     assert_valid_range_list(values)
     for u, v in values:
         for i in (u, v, (u + v) // 2):
-            cat = unicodedata.category(chr(i))
-            if include is not None:
-                assert cat in include
-            assert cat not in exclude
+            assert unicodedata.category(chr(i)) in cats
 
 
 @given(
-    st.sets(st.sampled_from(cm.categories())),
     st.sets(st.sampled_from(cm.categories())) | st.none(),
     st.integers(0, sys.maxunicode),
     st.integers(0, sys.maxunicode),
 )
-def test_query_matches_categories_codepoints(exclude, include, m1, m2):
+def test_query_matches_categories_codepoints(cats, m1, m2):
     m1, m2 = sorted((m1, m2))
-    values = cm.query(exclude, include, min_codepoint=m1, max_codepoint=m2).intervals
+    values = cm.query(categories=cats, min_codepoint=m1, max_codepoint=m2).intervals
     assert_valid_range_list(values)
     for u, v in values:
         assert m1 <= u
         assert v <= m2
 
 
-@given(st.sampled_from(cm.categories()), st.integers(0, sys.maxunicode))
-def test_exclude_only_excludes_from_that_category(cat, i):
-    c = chr(i)
-    assume(unicodedata.category(c) != cat)
-    intervals = cm.query(exclude_categories=(cat,)).intervals
-    assert any(a <= i <= b for a, b in intervals)
-
-
 def test_reload_charmap():
     x = cm.charmap()
     assert x is cm.charmap()
@@ -94,7 +80,7 @@ def test_recreate_charmap():
     x = cm.charmap()
     assert x is cm.charmap()
     cm._charmap = None
-    os.unlink(cm.charmap_file())
+    cm.charmap_file().unlink()
     y = cm.charmap()
     assert x is not y
     assert x == y
@@ -106,13 +92,13 @@ def test_uses_cached_charmap():
     # Reset the last-modified time of the cache file to a point in the past.
     mtime = int(time.time() - 1000)
     os.utime(cm.charmap_file(), (mtime, mtime))
-    statinfo = os.stat(cm.charmap_file())
+    statinfo = cm.charmap_file().stat()
     assert statinfo.st_mtime == mtime
 
     # Force reload of charmap from cache file and check that mtime is unchanged.
     cm._charmap = None
     cm.charmap()
-    statinfo = os.stat(cm.charmap_file())
+    statinfo = cm.charmap_file().stat()
     assert statinfo.st_mtime == mtime
 
 
@@ -170,10 +156,8 @@ def test_exception_in_write_does_not_lead_to_broken_charmap(monkeypatch):
 
 def test_regenerate_broken_charmap_file():
     cm.charmap()
-    file_loc = cm.charmap_file()
 
-    with open(file_loc, "wb"):
-        pass
+    cm.charmap_file().write_bytes(b"")  # overwrite with empty file
 
     cm._charmap = None
     cm.charmap()
@@ -194,8 +178,14 @@ def test_error_writing_charmap_file_is_suppressed(monkeypatch):
         # somebody tries to use it.
         saved = cm._charmap
         cm._charmap = None
-        os.unlink(cm.charmap_file())
+        cm.charmap_file().unlink()
 
         cm.charmap()
     finally:
         cm._charmap = saved
+
+
+def test_categoryname_literal_is_correct():
+    minor_categories = set(cm.categories())
+    major_categories = {c[0] for c in minor_categories}
+    assert set(get_args(cm.CategoryName)) == minor_categories | major_categories
