@@ -1,18 +1,14 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2020 David R. MacIver
-# (david@drmaciver.com), but it contains contributions by others. See
-# CONTRIBUTING.rst for a full list of people who may hold copyright, and
-# consult the git log if you need to determine who owns an individual
-# contribution.
+# Copyright the Hypothesis Authors.
+# Individual contributors are listed in AUTHORS.rst and the git log.
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
 # obtain one at https://mozilla.org/MPL/2.0/.
-#
-# END HEADER
 
+from hypothesis.internal.conjecture.utils import identity
 from hypothesis.internal.reflection import get_pretty_function_description
 
 
@@ -26,7 +22,7 @@ def test_no_whitespace_before_colon_with_no_args():
 
 def test_can_have_unicode_in_lambda_sources():
     t = lambda x: "é" not in x
-    assert get_pretty_function_description(t) == ('lambda x: "é" not in x')
+    assert get_pretty_function_description(t) == 'lambda x: "é" not in x'
 
 
 # fmt: off
@@ -170,10 +166,6 @@ def test_can_handle_brackets_in_decorator_argument():
     assert get_pretty_function_description(to_brackets[0]) == "lambda: ()"
 
 
-def identity(x):
-    return x
-
-
 @arg_decorator(identity(lambda x: x + 1))
 def decorator_with_wrapper():
     pass
