@@ -52,7 +52,7 @@ from tests.common.debug import (
     find_any,
     minimal,
 )
-from tests.common.utils import fails_with, temp_registered
+from tests.common.utils import Why, fails_with, temp_registered, xfail_on_crosshair
 
 sentinel = object()
 BUILTIN_TYPES = tuple(
@@ -619,6 +619,7 @@ class Tree:
         return f"Tree({self.left}, {self.right})"
 
 
+@pytest.mark.skipif(settings._current_profile == "crosshair", reason="takes ~19 mins")
 @given(tree=st.builds(Tree))
 def test_resolving_recursive_type(tree):
     assert isinstance(tree, Tree)
@@ -875,6 +876,7 @@ def test_supportsop_types_support_protocol(protocol, data):
     assert issubclass(type(value), protocol)
 
 
+@xfail_on_crosshair(Why.undiscovered)
 @pytest.mark.parametrize("restrict_custom_strategy", [True, False])
 def test_generic_aliases_can_be_conditionally_resolved_by_registered_function(
     restrict_custom_strategy,
@@ -979,6 +981,10 @@ def test_no_byteswarning(_):
     pass
 
 
+@pytest.mark.skipif(
+    settings._current_profile == "crosshair",
+    reason="Crosshair doesn't generate the Decimal('snan'), so this runs for hours",
+)
 def test_hashable_type_unhashable_value():
     # Decimal("snan") is not hashable; we should be able to generate it.
     # See https://github.com/HypothesisWorks/hypothesis/issues/2320
@@ -1237,3 +1243,21 @@ def test_from_type_resolves_required_posonly_args(n: CustomInteger):
     # st.builds() does not infer for positional arguments, but st.from_type()
     # does.  See e.g. https://stackoverflow.com/q/79199376/ for motivation.
     assert isinstance(n, CustomInteger)
+
+
+class MyProtocol(typing.Protocol):
+    pass
+
+
+def test_issue_4194_regression():
+    # this was an edge case where we were calling issubclass on something
+    # that was not a type, which errored. I don't have a more principled test
+    # case or name for this.
+    inner = typing.Union[typing.Sequence["A"], MyProtocol]
+    A = typing.Union[typing.Sequence[inner], MyProtocol]
+
+    with (
+        temp_registered(MyProtocol, st.just(b"")),
+        temp_registered(typing.ForwardRef("A"), st.integers()),
+    ):
+        find_any(st.from_type(A))
