@@ -1,24 +1,22 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2020 David R. MacIver
-# (david@drmaciver.com), but it contains contributions by others. See
-# CONTRIBUTING.rst for a full list of people who may hold copyright, and
-# consult the git log if you need to determine who owns an individual
-# contribution.
+# Copyright the Hypothesis Authors.
+# Individual contributors are listed in AUTHORS.rst and the git log.
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
 # obtain one at https://mozilla.org/MPL/2.0/.
-#
-# END HEADER
 
 import re
+from collections.abc import Sequence
+from typing import Union
 
 import pytest
 
 from hypothesis import given, strategies as st
 from hypothesis.errors import InvalidArgument
+
 from tests.common.debug import assert_no_examples
 
 
@@ -50,3 +48,18 @@ def test_one_of_without_strategies_suggests_sampled_from():
         match=re.escape("Did you mean st.sampled_from([1, 2, 3])?"),
     ):
         st.one_of(1, 2, 3)
+
+
+@pytest.mark.parametrize(
+    "strategy, count",
+    [
+        (st.one_of(st.integers(), st.integers(), st.integers()), 1),
+        (st.one_of(st.integers(), st.one_of(st.integers(), st.integers())), 2),
+        ((st.integers() | st.integers()) | st.integers(), 1),
+        (st.integers() | (st.integers() | st.integers()), 1),
+        (st.integers() | st.text() | st.booleans(), 1),
+        (st.from_type(Union[int, Sequence[int]]), 2),
+    ],
+)
+def test_one_of_unwrapping(strategy, count):
+    assert repr(strategy).count("one_of(") == count
