@@ -15,9 +15,8 @@ import django
 from django.conf import settings as django_settings
 from django.contrib.auth.models import User
 
-from hypothesis import HealthCheck, assume, given, settings
-from hypothesis.control import current_build_context, reject
-from hypothesis.errors import HypothesisException, InvalidArgument
+from hypothesis import HealthCheck, assume, given, settings, strategies as st
+from hypothesis.errors import InvalidArgument
 from hypothesis.extra.django import (
     TestCase,
     TransactionTestCase,
@@ -25,7 +24,7 @@ from hypothesis.extra.django import (
     register_field_strategy,
 )
 from hypothesis.internal.conjecture.data import ConjectureData
-from hypothesis.strategies import binary, just, lists
+from hypothesis.strategies import just, lists
 
 from tests.common.debug import check_can_generate_examples
 from tests.django.toystore.models import (
@@ -146,23 +145,19 @@ class TestGetsBasicModels(TestCase):
         # regression test for #1045.  Company just has a convenient CharField.
         assert "\x00" not in x.name
 
-    @given(binary(min_size=10))
-    def test_foreign_key_primary(self, buf):
+    @given(st.data())
+    def test_foreign_key_primary(self, data):
         # Regression test for #1307
         company_strategy = from_model(Company, name=just("test"))
         strategy = from_model(
             CompanyExtension, company=company_strategy, self_modifying=just(2)
         )
-        context = current_build_context()
-        try:
-            context.data = ConjectureData.for_buffer(buf)
-            context.data.draw(strategy)
-        except HypothesisException:
-            reject()
-        # Draw again with the same buffer. This will cause a duplicate
+        data.draw(strategy)
+
+        # Draw again with the same choice sequence. This will cause a duplicate
         # primary key.
-        context.data = ConjectureData.for_buffer(buf)
-        context.data.draw(strategy)
+        d = ConjectureData.for_choices(data.conjecture_data.choices)
+        d.draw(strategy)
         assert CompanyExtension.objects.all().count() == 1
 
 
@@ -223,7 +218,13 @@ if django.VERSION >= (5, 0, 0):
             Strategies are not inferred for GeneratedField.
             """
 
+            # Check we generate valid objects.
             pizza.full_clean()
+
+            # Refresh the instance from the database to make sure the
+            # generated fields are populated correctly.
+            pizza.refresh_from_db()
+
             # Check the expected types of the generated fields.
             self.assertIsInstance(pizza.slice_area, float)
             self.assertIsInstance(pizza.total_area, float)
