@@ -1,17 +1,12 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2020 David R. MacIver
-# (david@drmaciver.com), but it contains contributions by others. See
-# CONTRIBUTING.rst for a full list of people who may hold copyright, and
-# consult the git log if you need to determine who owns an individual
-# contribution.
+# Copyright the Hypothesis Authors.
+# Individual contributors are listed in AUTHORS.rst and the git log.
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
 # obtain one at https://mozilla.org/MPL/2.0/.
-#
-# END HEADER
 
 import gc
 import weakref
@@ -57,7 +52,7 @@ def test_cacheable_things_are_cached():
 
 
 def test_local_types_are_garbage_collected_issue_493():
-    store = [None]
+    store = None
 
     def run_locally():
         class Test:
@@ -66,11 +61,12 @@ def test_local_types_are_garbage_collected_issue_493():
             def test(self, i):
                 pass
 
-        store[0] = weakref.ref(Test)
+        nonlocal store
+        store = weakref.ref(Test)
         Test().test()
 
     run_locally()
     del run_locally
-    assert store[0]() is not None
+    assert store() is not None
     gc.collect()
-    assert store[0]() is None
+    assert store() is None
