@@ -14,10 +14,16 @@ from hypothesis.internal.conjecture.data import ConjectureData
 from hypothesis.internal.conjecture.engine import ConjectureRunner
 from hypothesis.internal.conjecture.shrinker import Shrinker, node_program
 
-from tests.common.utils import counts_calls, non_covering_examples
+from tests.common.utils import (
+    Why,
+    counts_calls,
+    non_covering_examples,
+    xfail_on_crosshair,
+)
 from tests.conjecture.common import run_to_nodes, shrinking_from
 
 
+@xfail_on_crosshair(Why.nested_given)
 def test_lot_of_dead_nodes():
     @run_to_nodes
     def nodes(data):
@@ -39,7 +45,7 @@ def test_saves_data_while_shrinking(monkeypatch):
     monkeypatch.setattr(
         ConjectureRunner,
         "generate_new_examples",
-        lambda runner: runner.cached_test_function_ir([bytes([255] * 10)]),
+        lambda runner: runner.cached_test_function([bytes([255] * 10)]),
     )
 
     def f(data):
@@ -65,7 +71,7 @@ def test_can_discard(monkeypatch):
     monkeypatch.setattr(
         ConjectureRunner,
         "generate_new_examples",
-        lambda runner: runner.cached_test_function_ir(
+        lambda runner: runner.cached_test_function(
             tuple(bytes(v) for i in range(n) for v in [i, i])
         ),
     )
@@ -80,6 +86,7 @@ def test_can_discard(monkeypatch):
     assert len(nodes) == n
 
 
+@xfail_on_crosshair(Why.nested_given)
 @given(st.integers(0, 255), st.integers(0, 255))
 def test_cached_with_masked_byte_agrees_with_results(a, b):
     def f(data):
@@ -87,8 +94,8 @@ def test_cached_with_masked_byte_agrees_with_results(a, b):
 
     runner = ConjectureRunner(f)
 
-    cached_a = runner.cached_test_function_ir([a])
-    cached_b = runner.cached_test_function_ir([b])
+    cached_a = runner.cached_test_function([a])
+    cached_b = runner.cached_test_function([b])
 
     data_b = ConjectureData.for_choices([b], observer=runner.tree.new_observer())
     runner.test_function(data_b)
