@@ -26,6 +26,7 @@ from hypothesis import (
 from hypothesis.internal.conjecture.data import Status
 from hypothesis.internal.conjecture.engine import ConjectureRunner
 
+from tests.common.utils import Why, xfail_on_crosshair
 from tests.conjecture.common import interesting_origin
 
 
@@ -115,6 +116,7 @@ def run_language_test_for(root, data, seed):
     assume(runner.interesting_examples)
 
 
+@xfail_on_crosshair(Why.nested_given)  # technically nested-engine, but same problem
 @settings(
     suppress_health_check=list(HealthCheck),
     deadline=None,
