@@ -11,7 +11,7 @@
 """
 This file tests for our ability to make precise shrinks.
 
-Terminology: A shrink is *precise* if there is a single example (draw call) that
+Terminology: A shrink is *precise* if there is a single span (draw call) that
 it replaces, without leaving any of the data before or after that draw call changed.
 Otherwise, it is sloppy.
 
@@ -59,6 +59,11 @@ from hypothesis.internal.conjecture.shrinker import sort_key
 
 T = TypeVar("T")
 
+pytestmark = pytest.mark.skipif(
+    settings._current_profile == "crosshair",
+    reason="using internals for testing in a way crosshair doesn't support",
+)
+
 
 def safe_draw(data, strategy):
     """Set up just enough of the Hypothesis machinery to use draw on
@@ -107,7 +112,7 @@ def precisely_shrink(
 
     runner = ConjectureRunner(test_function, random=random)
     try:
-        buf = runner.cached_test_function_ir(initial_choices)
+        buf = runner.cached_test_function(initial_choices)
         assert buf.status == Status.INTERESTING
         assert buf.choices == initial_choices
         assert runner.interesting_examples
@@ -238,7 +243,7 @@ def shrinks(strategy, nodes, *, allow_sloppy=True, seed=0):
             results[data.nodes] = value
 
         runner = ConjectureRunner(test_function, settings=settings(max_examples=10**9))
-        initial = runner.cached_test_function_ir(choices)
+        initial = runner.cached_test_function(choices)
         assert isinstance(initial, ConjectureResult)
         try:
             runner.shrink(initial, lambda x: x.choices == initial.choices)
@@ -260,7 +265,7 @@ def shrinks(strategy, nodes, *, allow_sloppy=True, seed=0):
                 results[key] = value
 
         runner = ConjectureRunner(test_function, settings=settings(max_examples=10**9))
-        initial = runner.cached_test_function_ir(initial_choices)
+        initial = runner.cached_test_function(initial_choices)
         assert len(results) == 1
         try:
             runner.shrink(initial, lambda x: x.choices == initial_choices)
