@@ -1,24 +1,24 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2020 David R. MacIver
-# (david@drmaciver.com), but it contains contributions by others. See
-# CONTRIBUTING.rst for a full list of people who may hold copyright, and
-# consult the git log if you need to determine who owns an individual
-# contribution.
+# Copyright the Hypothesis Authors.
+# Individual contributors are listed in AUTHORS.rst and the git log.
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
 # obtain one at https://mozilla.org/MPL/2.0/.
-#
-# END HEADER
 
 import unicodedata
 
+import pytest
+
 from hypothesis import given, settings
 from hypothesis.strategies import text
 
 
+@pytest.mark.skipif(
+    settings._current_profile == "crosshair", reason="takes ~10 minutes"
+)
 @given(text(min_size=1, max_size=1))
 @settings(max_examples=2000)
 def test_does_not_generate_surrogates(t):
