@@ -12,7 +12,7 @@ from typing import Dict as _Dict, ForwardRef, Union
 
 import pytest
 
-from hypothesis import given, strategies as st
+from hypothesis import given, settings, strategies as st
 from hypothesis.errors import ResolutionFailed
 
 from tests.common import utils
@@ -20,6 +20,8 @@ from tests.common import utils
 # Mutually-recursive types
 # See https://github.com/HypothesisWorks/hypothesis/issues/2722
 
+pytestmark = pytest.mark.skipif(settings._current_profile == "crosshair", reason="slow")
+
 
 @given(st.data())
 def test_mutually_recursive_types_with_typevar(data):
