@@ -1,17 +1,14 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2020 David R. MacIver
-# (david@drmaciver.com), but it contains contributions by others. See
-# CONTRIBUTING.rst for a full list of people who may hold copyright, and
-# consult the git log if you need to determine who owns an individual
-# contribution.
+# Copyright the Hypothesis Authors.
+# Individual contributors are listed in AUTHORS.rst and the git log.
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
 # obtain one at https://mozilla.org/MPL/2.0/.
-#
-# END HEADER
+
+import pytest
 
 from hypothesis import HealthCheck, Verbosity, assume, given, settings, strategies as st
 
@@ -22,6 +19,7 @@ def test_single_example(n):
     pass
 
 
+@pytest.mark.skipif(settings._current_profile == "crosshair", reason="hangs/crashes")
 @settings(
     max_examples=1,
     database=None,
