@@ -23,7 +23,7 @@ from hypothesis.extra._patching import (
 )
 from hypothesis.internal.compat import WINDOWS
 
-from .callables import WHERE, Cases, covered, fn
+from .callables import WHERE, Cases, covered, fn, undef_name
 from .toplevel import WHERE_TOP, fn_top
 
 SIMPLE = (
@@ -52,6 +52,11 @@ COVERING = (
     + "\n"
     + indent('@example(x=0).via("covering example")', prefix="+"),
 )
+UNDEF_NAME = (
+    undef_name,
+    ("undef_name(\n    array=array([100], dtype=int8),\n)", FAIL_MSG),
+    '+@example(array=np.array([100], dtype=np.int8)).via("discovered failure")',
+)
 
 
 def strip_trailing_whitespace(s):
@@ -74,9 +79,9 @@ def test_adds_simple_patch(tst, example, expected):
 
 
 SIMPLE_PATCH_BODY = f'''\
---- {WHERE}
-+++ {WHERE}
-@@ -18,6 +18,7 @@
+--- ./{WHERE}
++++ ./{WHERE}
+@@ -21,6 +21,7 @@
 
 
  @given(st.integers())
@@ -86,9 +91,9 @@ SIMPLE_PATCH_BODY = f'''\
 
 '''
 CASES_PATCH_BODY = f'''\
---- {WHERE}
-+++ {WHERE}
-@@ -25,6 +25,9 @@
+--- ./{WHERE}
++++ ./{WHERE}
+@@ -28,6 +28,9 @@
  class Cases:
      @example(n=0, label="whatever")
      @given(st.integers(), st.text())
@@ -98,8 +103,8 @@ CASES_PATCH_BODY = f'''\
 
 '''
 TOPLEVEL_PATCH_BODY = f'''\
---- {WHERE_TOP}
-+++ {WHERE_TOP}
+--- ./{WHERE_TOP}
++++ ./{WHERE_TOP}
 @@ -19,5 +19,6 @@
 
 
@@ -109,9 +114,9 @@ TOPLEVEL_PATCH_BODY = f'''\
      """A trivial test function."""
 '''
 COVERING_PATCH_BODY = f'''\
---- {WHERE}
-+++ {WHERE}
-@@ -31,7 +31,7 @@
+--- ./{WHERE}
++++ ./{WHERE}
+@@ -34,7 +34,7 @@
 
  @given(st.integers())
  @example(x=2).via("not a literal when repeated " * 2)
@@ -121,6 +126,19 @@ COVERING_PATCH_BODY = f'''\
 
 '''
 
+UNDEF_NAME_PATCH_BODY = f"""\
+--- ./{WHERE}
++++ ./{WHERE}
+@@ -40,6 +40,7 @@
+
+
+ @given(npst.arrays(np.int8, 1))
+{{0}}
+ def undef_name(array):
+     assert sum(array) < 100
+
+"""
+
 
 @pytest.mark.parametrize(
     "tst, example, expected, body, remove",
@@ -131,6 +149,7 @@ COVERING_PATCH_BODY = f'''\
         pytest.param(
             *COVERING, COVERING_PATCH_BODY, ("covering example",), id="covering"
         ),
+        pytest.param(*UNDEF_NAME, UNDEF_NAME_PATCH_BODY, (), id="undef_name"),
     ],
 )
 def test_make_full_patch(tst, example, expected, body, remove):
