@@ -1,26 +1,21 @@
 # This file is part of Hypothesis, which may be found at
 # https://github.com/HypothesisWorks/hypothesis/
 #
-# Most of this work is copyright (C) 2013-2020 David R. MacIver
-# (david@drmaciver.com), but it contains contributions by others. See
-# CONTRIBUTING.rst for a full list of people who may hold copyright, and
-# consult the git log if you need to determine who owns an individual
-# contribution.
+# Copyright the Hypothesis Authors.
+# Individual contributors are listed in AUTHORS.rst and the git log.
 #
 # This Source Code Form is subject to the terms of the Mozilla Public License,
 # v. 2.0. If a copy of the MPL was not distributed with this file, You can
 # obtain one at https://mozilla.org/MPL/2.0/.
-#
-# END HEADER
 
 TEST_DECORATORS_ALONE = """
 import hypothesis
-from hypothesis.strategies import composite
+from hypothesis.strategies import composite, none
 
 @composite
 def test_composite_is_not_a_test(draw):
     # This strategy will be instantiated, but no draws == no calls.
-    assert False
+    return draw(none())
 
 @hypothesis.seed(0)
 def test_seed_without_given_fails():
@@ -38,4 +33,6 @@ def test_repro_without_given_fails():
 
 def test_decorators_without_given_should_fail(testdir):
     script = testdir.makepyfile(TEST_DECORATORS_ALONE)
-    testdir.runpytest(script).assert_outcomes(failed=4)
+    result = testdir.runpytest(script)
+    result.assert_outcomes(failed=4)
+    assert "pytest_runtest_call" not in "\n".join(result.outlines)
